@@ -1,5 +1,5 @@
 mcmc.qpcr.classic <-
-function(fixed,random=NULL,data,controls,genebysample=TRUE,geneSpecRes=FALSE,center=T,...) {
+function(fixed=NULL,globalFixed=NULL,random=NULL,globalRandom=NULL,data,controls,genebysample=TRUE,geneSpecRes=FALSE,center=TRUE,...) {
 	ngenes=length(levels(data[,"gene"]))
 
 #checking if there are technical reps
@@ -8,18 +8,29 @@ function(fixed,random=NULL,data,controls,genebysample=TRUE,geneSpecRes=FALSE,cen
 	if (length(levels(ss$sample))<length(ss[,1])) reps=1 else reps=0
 	
 # assembling the fixed effects formula:
+	if (!is.null(globalFixed)) {
+		gfs=paste(globalFixed,collapse="+")
+		gfs=paste(gfs,"+",sep="")
+	} else { gfs="" }
 	if (is.null(fixed)) {
-		ff="count~0+gene"
+		ff=paste("count~0+",gfs,"gene",sep="")
 	} else {
 		ff=gsub('\\s?\\+\\s?',"+gene:",x=fixed,perl=TRUE)
-		ff=paste("count~0+gene+gene:",ff,sep="")
+		ff=paste("count~0+gene+",gfs,"+gene:",ff,sep="")
 	}	
 
 # assembling the random effects formula:
+#	globalRandom="tank"
+
 	rr="~"
+	if (!is.null(globalRandom)) {
+		grs=paste(globalRandom,collapse="+")
+#		grs=paste(grs,"+",sep="")
+	} else { grs="" }
+	rr=paste(rr,grs,sep="")
 	if(genebysample)	random=append(random,"sample")
 	for (r in random){
-			if (r==random[1]) rr=paste(rr,"idh(gene):",r,sep="") else rr=paste(rr,"+idh(gene):",r,sep="") 
+			if (r==random[1] && is.null(globalRandom)) rr=paste(rr,"idh(gene):",r,sep="") else rr=paste(rr,"+idh(gene):",r,sep="") 
 	}
 # moving controls to the end of the factor list (for variance fixing later)
 	controls=controls[length(controls):1]
@@ -34,6 +45,7 @@ function(fixed,random=NULL,data,controls,genebysample=TRUE,geneSpecRes=FALSE,cen
 	data[,"gene"]=factor(data[,"gene"],levels=relev)
 
 	ddn=normalize.qpcr(data,controls,center)
+	print(list("FIXED"=ff,"RANDOM"=rr))
 	if (geneSpecRes){
 		if (rr=="~") {
 			mc=MCMCglmm(formula(ff),rcov=~idh(gene):units,data=ddn,...)
